nxp-pac

Crates

git

Versions

mcxa577

Flavors

GlbCcClr

Struct GlbCcClr 

#[repr(transparent)]
pub struct GlbCcClr(pub u32);
AHB Clock Control Clear 0

Tuple Fields

0: u32

Implementations

Source

impl GlbCcClr

pub const fn data(&self) -> u32

Data array value, refer to corresponding position in MRCC_GLB_CCn.

pub const fn set_data(&mut self, val: u32)

Data array value, refer to corresponding position in MRCC_GLB_CCn.