nxp-pac

Crates

git

Versions

mcxa577

Flavors

GlbRstClr

Struct GlbRstClr 

#[repr(transparent)]
pub struct GlbRstClr(pub u32);
Peripheral Reset Control Clear 0

Tuple Fields

0: u32

Implementations

Source

impl GlbRstClr

pub const fn data(&self) -> u32

Data array value, refer to corresponding position in MRCC_GLB_RSTn.

pub const fn set_data(&mut self, val: u32)

Data array value, refer to corresponding position in MRCC_GLB_RSTn.